@@ -12,10 +12,9 @@ $session->set_output_as_file('out/resolver.pdf');
 
 //リソースの送信
 function resolver($uri, $r) {
-  $file = "data/$uri";
-  if (file_exists($file)) {
+  if (file_exists($uri)) {
   	$r->start();
-  	readfile($file);
+  	readfile($uri);
   	$r->end();
   }
 }
@@ -23,7 +22,7 @@ $func = 'resolver';
 $session->set_resolver_func($func);
 	
 //文書の送信
-$session->start_main('test.html');
+$session->start_main('data/test.html');
 readfile("data/test.html");
 $session->end_main();
 
